import acoustid
import sys
import urllib.request
import pkg_resources
import os
import json
import ntpath
import discogs_client
import pickle

DATA_PATH = pkg_resources.resource_filename('titanium_rhythm', 'song_info/')
JSON_FILE = pkg_resources.resource_filename('titanium_rhythm', os.path.join('info', 'info.json'))


class Identify():
	def __init__(self, filename):
		self.get_info()
		self.filename = filename
	
	def get_info(self):
		with open(JSON_FILE, 'r') as f:
			self.info = json.load(f)
		self.api_key = self.info['api_key']
		
	def aidmatch(self, xml_required = False, pickle_required = False):
		try:
			results = acoustid.match(self.api_key, self.filename)
		except acoustid.NoBackendError:
			print("chromaprint library/tool not found", file=sys.stderr)
			sys.exit(1)
		except acoustid.FingerprintGenerationError:
			print("fingerprint could not be calculated", file=sys.stderr)
			sys.exit(1)
		except acoustid.WebServiceError as exc:
			print("web service request failed:", exc.message, file=sys.stderr)
			sys.exit(1)
		
		if(xml_required == True):
			for score, rid, title, artist in results:
				url = "https://musicbrainz.org/ws/2/recording/{0}?inc=aliases%2Bartist-credits%2Breleases".format(rid)
				response = urllib.request.urlopen(url)
				data = response.read()      # a `bytes` object
				text = data.decode('utf-8') # a `str`; this step can't be used if data is binary
				basename = ntpath.basename(self.filename)
				XML_FILE = pkg_resources.resource_filename('titanium_rhythm', os.path.join('song_info', basename[:-4]+'.xml'))
				with open(XML_FILE, 'w') as f:
					print(text, file = f)
		
		if(pickle_required == True):
			d = discogs_client.Client('ExampleApplication/0.1', user_token="vqhbRQaPOlwDSVqSNXovPSgwltksFddGjifKGNRS")
			for score, rid, title, artist in results:
				results = d.search(title+' '+artist, type = 'release')
				basename = ntpath.basename(self.filename)
				PICKLE_FILE = pkg_resources.resource_filename('titanium_rhythm', os.path.join('song_info', basename[:-4]+'.pkl'))
				with open(PICKLE_FILE, 'wb') as f:
					pickle.dump(results, f, pickle.HIGHEST_PROTOCOL)
				return PICKLE_FILE

if __name__ == '__main__':
	i = Identify(sys.argv[1])
	i.aidmatch()
	# PMaILC8xG3



import pickle

from titanium_rhythm.modify import Song
from titanium_rhythm.identify import Identify
from titanium_rhythm.setup_api import Setup

def annotate_file(key, song_file):
	Setup.set_key(key)
	i = Identify(song_file)
	pickle_file = i.aidmatch(pickle_required = True)
	with open(pickle_file, 'rb') as f:
		data = pickle.load(f)
	
	s = Song(song_file)
	s.modify_title(data[0].title)
	s.modify_artist(data[0].artists[0].name)
	s.modify_image_path(data[0].images[0]['uri'])
	s.modify_filename(data[0].title+'.mp3')


import setuptools

with open("README.md", "r") as fh:
   long_description = fh.read()

setuptools.setup(
    name="titanium_rhythm",
    version="1.0.0",
    author="Ganesh Kathiresan",
    author_email="ganesh3597@gmail.com",
    description="Automatic id3 modifier .mp3 files",
	long_description=long_description,
	long_description_content_type="text/markdown",
    url="https://github.com/DarkFate13/titanium-rhythm",
	packages=['titanium_rhythm'],
	package_dir = {'titanium_rhythm': 'titanium_rhythm/'},
	package_data={'titanium_rhythm': ['info/*.*', 'song_info/*.xml']},
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
	install_requires=[
          'discogs_client == 2.2.1',
		  'eyeD3 == 0.8.7',
		  'pyacoustid == 1.1.5',
		  'pytest == 3.6.1',
		  'requests == 2.18.4',
		  'setuptools == 38.6.0',
		  'validators == 0.12.2',
      ],
)



import json
import pkg_resources
import os

DATA_PATH = pkg_resources.resource_filename('titanium_rhythm', 'info/')
JSON_FILE = pkg_resources.resource_filename('titanium_rhythm', os.path.join('info', 'info.json'))

class Setup():
	def __init__(self):
		pass
	
	@staticmethod
	def set_key(key):
		info = dict()
		info['api_key'] = key
		with open(JSON_FILE, 'w') as f:
			json.dump(info, f, indent = 4)
	
	@staticmethod
	def get_key():
		with open(JSON_FILE, 'r') as f:
			info = json.load(f)
		
		return info
			